@@ -1,11 +1,6 @@
 library(DanielBiostatistics10th)
-# To run a line of code, use shortcut
-# Command + Enter: Mac and RStudio Cloud
-# Control + Enter: Windows, Mac and RStudio Cloud
-# To clear the console
-# Control + L: Mac and RStudio Cloud
-
-library(car) # car::scatterplot
+library(car)
+library(DescTools)
 
 # Page 540, Example 11.1.1
 d1111 = read.csv(system.file('extdata', 'EXA_C11_S01_01.csv', package = 'DanielBiostatistics10th'))
@@ -23,13 +18,13 @@ d1121a = within(d1121, expr = {
   SMOKE = as.logical(SMOKE)
 })
 xlab1121 = 'Length of gestation (weeks)'; ylab1121 = 'Birth weight (grams)'
-scatterplot(GRAMS ~ WEEKS | SMOKE, data = d1121a, regLine = FALSE, smooth = FALSE,
-            xlab = xlab1121, ylab = ylab1121, main = 'Page 547, Figure 11.2.1')
+car::scatterplot(GRAMS ~ WEEKS | SMOKE, data = d1121a, regLine = FALSE, smooth = FALSE,
+                 xlab = xlab1121, ylab = ylab1121, main = 'Page 547, Figure 11.2.1')
 # Page 547, Figure 11.2.2: main model (without interaction)
 summary(m1121_main <- lm(GRAMS ~ WEEKS + SMOKE, data = d1121a))
 confint(m1121_main)
-scatterplot(GRAMS ~ WEEKS | SMOKE, data = d1121a, regLine = FALSE, smooth = FALSE,
-            xlab = xlab1121, ylab = ylab1121, main = 'Page 548, Figure 11.2.3')
+car::scatterplot(GRAMS ~ WEEKS | SMOKE, data = d1121a, regLine = FALSE, smooth = FALSE,
+                 xlab = xlab1121, ylab = ylab1121, main = 'Page 548, Figure 11.2.3')
 (cf_main = m1121_main$coefficients)
 abline(a = cf_main[1L], b = cf_main[2L], col = 'blue') # regression line for non-smoking mothers
 abline(a = cf_main[1L] + cf_main[3L], b = cf_main[2L], col = 'magenta') 
@@ -41,20 +36,20 @@ d1123a = within(d1123, expr = {
 })
 summary(mod_1123 <- lm(EFFECT ~ AGE * METHOD, data = d1123a)) # Page 555, Figure 11.2.5
 confint(mod_1123)
-scatterplot(EFFECT ~ AGE | METHOD, data = d1123a, smooth = FALSE,
-            xlab = 'Age', ylab = 'Treatment effectiveness', main = 'Page 555, Figure 11.2.6')
+car::scatterplot(EFFECT ~ AGE | METHOD, data = d1123a, smooth = FALSE,
+                 xlab = 'Age', ylab = 'Treatment effectiveness', main = 'Page 555, Figure 11.2.6')
 
 # (optional) Page 561, Example 11.3.1
-d1131 = read.csv(system.file('extdata', 'EXA_C11_S03_01_corrected.csv', 
-                             package = 'DanielBiostatistics10th'))
+d1131 = read.csv(system.file('extdata', 'EXA_C11_S03_01.csv', package = 'DanielBiostatistics10th'))
+head(d1131)
+names(d1131) = c('JOBPER', 'ASRV', 'ENTH', 'AMB', 'COMM', 'PROB', 'INIT')
 summary(mod_1131_raw <- lm(JOBPER ~ ASRV + ENTH + AMB + COMM + PROB + INIT, data = d1131))
 # summary(mod_1131 <- MASS::stepAIC(mod_1131_raw, direction = 'backward'))
 # the stepwise selection criterion used in MINITAB is not necessarily AIC
 
 # Page 572, Example 11.4.1
-(d1141 = array(c(92L, 21L, 15L, 20L), dim = c(2L, 2L),
-               dimnames = list(OCAD = c('Present', 'Absent'), Sex = c('Male', 'Female'))))
-addmargins(d1141) # Page 572, Table 11.4.2
+addmargins(d1141 <- array(c(92L, 21L, 15L, 20L), dim = c(2L, 2L), dimnames = list(
+  OCAD = c('Present', 'Absent'), Sex = c('Male', 'Female')))) # Page 572, Table 11.4.2
 (d1141a = within(as.data.frame(as.table(d1141)), expr = {
   OCAD = (OCAD == 'Present')
   Sex = factor(Sex, levels = c('Female', 'Male'))
@@ -78,11 +73,10 @@ d1143 = read.csv(system.file('extdata', 'REV_C11_24.csv', package = 'DanielBiost
 summary(glm(ONSET ~ HIAA + TRYPT, family = binomial(link = 'logit'), data = d1143)) 
 # Page 577, Figure 11.4.4
 # Predictor TRYPT should be removed from model due to p-value \approx 1 
+summary(glm(ONSET ~ HIAA, family = binomial(link = 'logit'), data = d1143)) 
 
 # (optional) Page 578, Example 11.4.4
-# library(DescTools)
-# PseudoR2(mod_1142, which = 'CoxSnell')
-# PseudoR2(mod_1142, which = 'Nagelkerke')
+DescTools::PseudoR2(mod_1142, which = 'CoxSnell')
+DescTools::PseudoR2(mod_1142, which = 'Nagelkerke')
 
 # (optional) Page 579, Example 11.4.5 (same as Example 11.4.4)
-
